@@ -108,10 +108,11 @@ def getDataFieldValue(dataField):
         return keys[0]
 
     if dataField.type == 'file':
-        if dataField.file is None:
-            return None
 
-        return File(dataField.file, dataField.__user__)
+        if len(dataField.files) == 1:
+            return File(dataField.files[0], dataField.__user__)
+        else:
+            return EntityList(dataField.files, File, dataField.__user__)
 
     return None
 
