@@ -8,12 +8,13 @@ from labstep.service.helpers import url_join, getHeaders
 from labstep.entities.file.model import File
 from labstep.service.request import requestService
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
-def newFile(user, filepath=None, rawData=None, extraParams={}):
-    if filepath is not None:
+def newFile(user, filepath=UNSPECIFIED, rawData=UNSPECIFIED, extraParams={}):
+    if filepath is not UNSPECIFIED:
         rawData = open(filepath, 'rb')
-    if rawData is None:
+    if rawData is UNSPECIFIED:
         raise Exception('Please specify filepath or raw data')
 
     files = {'file': rawData}
@@ -27,21 +28,25 @@ def newFile(user, filepath=None, rawData=None, extraParams={}):
 
 
 def getFile(user, fileId):
-    return entityRepository.getEntity(user, File, fileId, isDeleted=None)
+    return entityRepository.getEntity(user, File, fileId, isDeleted=UNSPECIFIED)
 
 
-def downloadFile(user, fileId):
+def getFileDownloadLink(user, fileId):
     headers = getHeaders(user=user)
     url = url_join(configService.getHost(),
                    "/api/generic/file/download", str(fileId))
     response = requestService.post(url, headers=headers)
-    rawData = requestService.get(json.loads(response.content)[
-        "signed_url"], headers=None).content
-    return rawData
+    return json.loads(response.content)["signed_url"]
+
+
+def downloadFile(user, fileId):
+    downloadLink = getFileDownloadLink(user, fileId)
+    response = requestService.get(downloadLink, headers=None)
+    return response.content
 
 
 def getFiles(
-    user, count=100, search_query=None, file_type=None, extraParams={}
+    user, count=100, search_query=UNSPECIFIED, file_type=UNSPECIFIED, extraParams={}
 ):
     params = {"search_query": search_query,
               "filetype": file_type, **extraParams}
