@@ -5,6 +5,7 @@
 from labstep.entities.resourceItem.model import ResourceItem
 import labstep.generic.entity.repository as entityRepository
 from labstep.service.helpers import handleKeyword
+from labstep.constants import UNSPECIFIED
 
 
 def getResourceItem(user, resourceItem_id):
@@ -12,7 +13,7 @@ def getResourceItem(user, resourceItem_id):
 
 
 def getResourceItems(
-    user, resource_id=None, count=100, search_query=None, extraParams={}
+    user, resource_id=UNSPECIFIED, count=100, search_query=UNSPECIFIED, extraParams={}
 ):
     params = {
         "search_query": search_query,
@@ -25,11 +26,11 @@ def getResourceItems(
 def newResourceItem(
     user,
     resource_id,
-    name=None,
-    availability=None,
-    quantity_amount=None,
-    quantity_unit=None,
-    resource_location_id=None,
+    name=UNSPECIFIED,
+    availability=UNSPECIFIED,
+    quantity_amount=UNSPECIFIED,
+    quantity_unit=UNSPECIFIED,
+    resource_location_id=UNSPECIFIED,
     extraParams={},
 ):
     params = {
@@ -47,12 +48,12 @@ def newResourceItem(
 
 def editResourceItem(
     resourceItem,
-    name=None,
-    availability=None,
-    quantity_amount=None,
-    quantity_unit=None,
-    resource_location_id=None,
-    deleted_at=None,
+    name=UNSPECIFIED,
+    availability=UNSPECIFIED,
+    quantity_amount=UNSPECIFIED,
+    quantity_unit=UNSPECIFIED,
+    resource_location_id=UNSPECIFIED,
+    deleted_at=UNSPECIFIED,
     extraParams={},
 ):
     params = {
@@ -64,7 +65,7 @@ def editResourceItem(
         **extraParams,
     }
 
-    if quantity_amount is not None:
+    if quantity_amount is not UNSPECIFIED:
         params["quantity_amount"] = float(quantity_amount)
 
     return entityRepository.editEntity(resourceItem, params)
