@@ -46,7 +46,7 @@ def getEntities(user, entityClass, count, filterParams={}):
     countParameter = min(
         count, 50) if count is not UNSPECIFIED else UNSPECIFIED
 
-    if entityClass == Export:
+    if getattr(entityClass, "__unSearchable__", None):
         searchParams = {"cursor": -1, "count": countParameter}
     else:
         searchParams = {"search": 1, "cursor": -1, "count": countParameter}
@@ -125,6 +125,16 @@ def editEntity(entity, fields):
     return entity
 
 
+def deleteEntity(entity):
+    identifier = entity.guid if getattr(
+        entity, "__hasGuid__", None) and hasattr(entity, 'guid') else entity.id
+
+    headers = getHeaders(entity.__user__)
+    url = url_join(configService.getHost(), "/api/generic/",
+                   entity.__entityName__, str(identifier))
+    return requestService.delete(url, headers=headers)
+
+
 def exportEntity(entity, rootPath, folderName=UNSPECIFIED):
 
     from labstep.entities.file.model import File
